import logging

from fastapi import Depends, FastAPI, HTTPException, status, responses

from gisaf.models.admin import AdminBasket, BasketNameOnly
from gisaf.models.authentication import User
from gisaf.security import get_current_active_user
from gisaf.admin import manager

logger = logging.getLogger(__name__)

api = FastAPI(
    default_response_class=responses.ORJSONResponse,
)

@api.get('/basket')
async def get_baskets(
    user: User = Depends(get_current_active_user),
    ):
    return [
        BasketNameOnly(name=name)
        for name, basket in (await manager.baskets_for_role(user)).items()
    ]

@api.get('/basket/{name}')
async def get_basket(
    name: str,
    user: User = Depends(get_current_active_user),
    ) -> AdminBasket:
    basket = manager.baskets[name]
    if basket.role and not user.has_role(basket.role):
        raise HTTPException(status.HTTP_401_UNAUTHORIZED)
    return AdminBasket(
        name=name,
        files=await basket.get_files(),
        columns=basket.columns,
        uploadFields=basket.upload_fields,
        ## TODO: Fix projects
        # projects=getattr(basket, 'projects', None)
    )
