import logging
from contextlib import asynccontextmanager

from fastapi import FastAPI, responses

from gisaf.api.v2 import api
from gisaf.api.geoapi import api as geoapi
from gisaf.config import conf
from gisaf.registry import registry
from gisaf.redis_tools import setup_redis, setup_redis_cache, shutdown_redis
from gisaf.tiles import registry as map_tile_registry
from gisaf.live import setup_live
from gisaf.admin import manager as admin_manager
from gisaf.api.admin import api as admin_api

logging.basicConfig(level=conf.gisaf.debugLevel)
logger = logging.getLogger(__name__)


@asynccontextmanager
async def lifespan(app: FastAPI):
    await registry.make_registry()
    await setup_redis()
    await setup_redis_cache()
    await setup_live()
    await admin_manager.setup_admin()
    await map_tile_registry.setup()
    yield
    await shutdown_redis()
    await map_tile_registry.shutdown()

app = FastAPI(
    debug=False,
    title=conf.gisaf.title,
    version=conf.version,
    lifespan=lifespan,
    default_response_class=responses.ORJSONResponse,
)

app.mount('/v2', api)
app.mount('/gj', geoapi)
app.mount('/admin', admin_api)